@@ -3,7 +3,7 @@ package Devel::TraceRun;
 use strict;
 use warnings;
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 {
   package DB;
@@ -69,6 +69,56 @@ so that differences stand out.
 The output is on C<STDOUT> currently. That may become overridable in
 due course.
 
+=head2 Example
+
+This code (from the test - C<Thing::func> calls C<Thing::func2> which
+returns "2nd retval"):
+
+  use Thing;
+  my $f = sub { Thing::func() };
+  Thing::func([2]); # void
+  my @r = Thing::func([2]);
+  my @r2 = $f->("very long string", 2, bless {}, 'Thing');
+
+run with:
+
+  perl -d -d:TraceRun script.pl
+
+produces on perl 5.8 - 5.14 (output is slightly different from 5.16,
+and again from 5.28):
+
+  main::(script.pl:1)()
+  return()
+  Thing::func(ARRAY)
+    Thing::func2()
+    return()
+  return()
+  Thing::func(ARRAY)
+    Thing::func2()
+    return(2nd retval)
+  return(2nd retval)
+  main entry(very long ,2,Thing)
+    Thing::func()
+      Thing::func2()
+      return(2nd retval)
+    return(2nd retval)
+  return(2nd retval)
+
+Note that in void context, nothing is returned. Also note the C<very long
+string> is truncated to (currently) 10 characters, array- and hash-refs
+are printed just as C<ARRAY> and C<HASH>, and objects as their classname.
+
+There is currently no way to change what is printed. One thing that would
+increase homogeneity across runs would be a way to specify for certain
+function-names, which inputs or outputs to mask. Obvious examples where
+this would help are functions that return the current time, or a random
+number, or the port number of an incoming IP connection.
+
+Another source of output variation is the change in Perl 5.18 to randomise
+the order hash-keys are returned in. You can overcome this for tracing
+purposes by setting the environment variable C<PERL_HASH_SEED> to 0,
+which also has the effect of setting C<PERL_PERTURB_KEYS> to 0.
+
 =head2 How it works
 
 As may be discerned from the command line, it uses Perl's debugging
